pub enum ProbeClientError {
ServiceProbeEndpointUnavailable {
source: Error,
},
}Expand description
The error that can happen during startup of the service probe.
Variants
The socket cannot be used for providing the service probe.